Title: [259809] trunk/Tools
Revision
259809
Author
aakash_j...@apple.com
Date
2020-04-09 11:17:56 -0700 (Thu, 09 Apr 2020)

Log Message

[ews] rename CompileJSCToT to CompileJSCWithoutPatch
https://bugs.webkit.org/show_bug.cgi?id=210265

Reviewed by Jonathan Bedard.

* BuildSlaveSupport/ews-build/steps.py:
(CompileWebKitWithoutPatch): Drive-by fix to rename similar name.
(AnalyzeCompileWebKitResults.start): Ditto.
(CompileWebKit.evaluateCommand): Renamed CompileJSCToT to CompileJSCWithoutPatch.
(CompileJSCWithoutPatch): Ditto.
(ReRunJavaScriptCoreTests.evaluateCommand): Ditto.
* BuildSlaveSupport/ews-build/steps_unittest.py: Updated unit-tests.

Modified Paths

Diff

Modified: trunk/Tools/BuildSlaveSupport/ews-build/steps.py (259808 => 259809)


--- trunk/Tools/BuildSlaveSupport/ews-build/steps.py	2020-04-09 18:14:37 UTC (rev 259808)
+++ trunk/Tools/BuildSlaveSupport/ews-build/steps.py	2020-04-09 18:17:56 UTC (rev 259809)
@@ -1308,7 +1308,7 @@
             elif platform == 'gtk':
                 steps_to_add.append(InstallGtkDependencies())
             if self.getProperty('group') == 'jsc':
-                steps_to_add.append(CompileJSCToT())
+                steps_to_add.append(CompileJSCWithoutPatch())
             else:
                 steps_to_add.append(CompileWebKitWithoutPatch())
             steps_to_add.append(AnalyzeCompileWebKitResults())
@@ -1328,7 +1328,7 @@
 
 
 class CompileWebKitWithoutPatch(CompileWebKit):
-    name = 'compile-webkit-tot'
+    name = 'compile-webkit-without-patch'
     haltOnFailure = False
 
     def doStepIf(self, step):
@@ -1347,12 +1347,12 @@
     descriptionDone = ['analyze-compile-webkit-results']
 
     def start(self):
-        compile_tot_step = CompileWebKitWithoutPatch.name
+        compile_without_patch_step = CompileWebKitWithoutPatch.name
         if self.getProperty('group') == 'jsc':
-            compile_tot_step = CompileJSCToT.name
-        compile_webkit_tot_result = self.getStepResult(compile_tot_step)
+            compile_without_patch_step = CompileJSCWithoutPatch.name
+        compile_without_patch_result = self.getStepResult(compile_without_patch_step)
 
-        if compile_webkit_tot_result == FAILURE:
+        if compile_without_patch_result == FAILURE:
             self.finished(FAILURE)
             message = 'Unable to build WebKit without patch, retrying build'
             self.descriptionDone = message
@@ -1394,8 +1394,8 @@
         return shell.Compile.getResultSummary(self)
 
 
-class CompileJSCToT(CompileJSC):
-    name = 'compile-jsc-tot'
+class CompileJSCWithoutPatch(CompileJSC):
+    name = 'compile-jsc-without-patch'
 
     def evaluateCommand(self, cmd):
         return shell.Compile.evaluateCommand(self, cmd)
@@ -1514,7 +1514,7 @@
             self.setProperty('patchFailedTests', True)
             self.build.addStepsAfterCurrentStep([UnApplyPatchIfRequired(),
                                                 ValidatePatch(verifyBugClosed=False, addURLs=False),
-                                                CompileJSCToT(),
+                                                CompileJSCWithoutPatch(),
                                                 ValidatePatch(verifyBugClosed=False, addURLs=False),
                                                 KillOldProcesses(),
                                                 RunJSCTestsWithoutPatch(),

Modified: trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py (259808 => 259809)


--- trunk/Tools/ChangeLog	2020-04-09 18:14:37 UTC (rev 259808)
+++ trunk/Tools/ChangeLog	2020-04-09 18:17:56 UTC (rev 259809)
@@ -1,3 +1,18 @@
+2020-04-09  Aakash Jain  <aakash_j...@apple.com>
+
+        [ews] rename CompileJSCToT to CompileJSCWithoutPatch
+        https://bugs.webkit.org/show_bug.cgi?id=210265
+
+        Reviewed by Jonathan Bedard.
+
+        * BuildSlaveSupport/ews-build/steps.py:
+        (CompileWebKitWithoutPatch): Drive-by fix to rename similar name.
+        (AnalyzeCompileWebKitResults.start): Ditto.
+        (CompileWebKit.evaluateCommand): Renamed CompileJSCToT to CompileJSCWithoutPatch.
+        (CompileJSCWithoutPatch): Ditto.
+        (ReRunJavaScriptCoreTests.evaluateCommand): Ditto.
+        * BuildSlaveSupport/ews-build/steps_unittest.py: Updated unit-tests.
+
 2020-04-09  Claudio Saavedra  <csaave...@igalia.com>
 
         [GTK] Clean-up use of deprecated GtkAction
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py	2020-04-09 18:14:37 UTC (rev 259808)
+++ trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py	2020-04-09 18:17:56 UTC (rev 259809)
@@ -37,7 +37,7 @@
 from steps import (AnalyzeAPITestsResults, AnalyzeCompileWebKitResults, AnalyzeJSCTestsResults,
                    AnalyzeLayoutTestsResults, ApplyPatch, ApplyWatchList, ArchiveBuiltProduct, ArchiveTestResults,
                    CheckOutSource, CheckOutSpecificRevision, CheckPatchRelevance, CheckPatchStatusOnEWSQueues, CheckStyle,
                    CleanBuild, CleanUpGitIndexLock, CleanWorkingDirectory, CompileJSC, CompileJSCToT, CompileWebKit,
                    CompileWebKitWithoutPatch, ConfigureBuild, CreateLocalGITCommit,
                    DownloadBuiltProduct, DownloadBuiltProductFromMaster, ExtractBuiltProduct, ExtractTestResults,
                    FindModifiedChangeLogs, InstallGtkDependencies, InstallWpeDependencies, KillOldProcesses,
@@ -1082,7 +1082,7 @@
         self.assertEqual(self.getProperty('build_finish_summary'), 'Patch 1234 does not build')
         return rc
 
-    def test_patch_with_ToT_failure(self):
+    def test_patch_with_trunk_failure(self):
         previous_steps = [
             mock_step(CompileWebKit(), results=FAILURE),
             mock_step(CompileWebKitWithoutPatch(), results=FAILURE),
@@ -1130,7 +1130,7 @@
         return self.runStep()
 
 
-class TestCompileJSCToT(BuildStepMixinAdditions, unittest.TestCase):
+class TestCompileJSCWithoutPatch(BuildStepMixinAdditions, unittest.TestCase):
     def setUp(self):
         self.longMessage = True
         return self.setUpBuildStep()
@@ -1139,7 +1139,7 @@
         return self.tearDownBuildStep()
 
     def test_success(self):
-        self.setupStep(CompileJSCToT())
+        self.setupStep(CompileJSCWithoutPatch())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'release')
         self.setProperty('patchFailedToBuild', 'True')
@@ -1154,7 +1154,7 @@
         return self.runStep()
 
     def test_failure(self):
-        self.setupStep(CompileJSCToT())
+        self.setupStep(CompileJSCWithoutPatch())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'debug')
         self.expectRemoteCommands(
@@ -37,7 +37,7 @@
                    AnalyzeLayoutTestsResults, ApplyPatch, ApplyWatchList, ArchiveBuiltProduct, ArchiveTestResults,
                    CheckOutSource, CheckOutSpecificRevision, CheckPatchRelevance, CheckPatchStatusOnEWSQueues, CheckStyle,
-                   CleanBuild, CleanUpGitIndexLock, CleanWorkingDirectory, CompileJSC, CompileJSCToT, CompileWebKit,
+                   CleanBuild, CleanUpGitIndexLock, CleanWorkingDirectory, CompileJSC, CompileJSCWithoutPatch, CompileWebKit,
                    CompileWebKitWithoutPatch, ConfigureBuild, CreateLocalGITCommit,
                    DownloadBuiltProduct, DownloadBuiltProductFromMaster, ExtractBuiltProduct, ExtractTestResults,

Modified: trunk/Tools/ChangeLog (259808 => 259809)

